package Acme::MetaSyntactic::vcs;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::vcs - The vcs theme

=head1 DESCRIPTION

This theme lists popular (and not so popular) Version Control systems.

=head1 CONTRIBUTOR

ric Cholet

Introduced in Acme-MetaSyntactic version 0.91, published on September 11, 2006.

Updated by Abigail in version 0.92, published on September 18, 2006.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

Updated with an C<=encoding> pod command in version 1.001,
published on May 14,2012

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
accurev
aegis
aldon_lifecycle_manager
alienbrain
allchange
allfusion_harvest_change_manager
arch
archipel
arx
asvcs
bazaar
bazaar_ng
bitkeeper
bky
changelogic
clearcase
code_co_op
codeville
cogito
controltier
CS_RCS
CSSC
cvs
cvsnt
cvs_suite
darcs
dcvs
dvs
evolution
fastcst
gat
git
ic_manage
jedi_vcs
katie
m_files
matrixone
mecasp
mercurial
meta_cvs
MKS
monotone
opencm
opencvs
Perforce
prcs
projector
QVCS
quilt
razor
RCS
rmtrcs
sccs
sdf
serena_changeman
serena_version_manager
siveco
slash_briefcase
snapshotcm
so6
sourceanywhere
sourcehaven
sourcejammer
starteam
stellation
surround_SCM
svk
Subversion
superversion
team_foundation_server
teamware
telelogic_synergy
TLIB
truechange
vault
vesta
Visual_SourceSafe
workshare_professional
